@@ -24,7 +24,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut chart = ChartBuilder::on(&root)
         .set_label_area_size(LabelAreaPosition::Left, 60)
         .set_label_area_size(LabelAreaPosition::Bottom, 60)
-        .caption("Area Chart Demo", ("Arial", 40))
+        .caption("Area Chart Demo", ("sans-serif", 40))
         .build_ranged(0..(data.len() - 1), 0.0..1500.0)?;
 
     chart
