@@ -17,7 +17,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     root.fill(&WHITE)?;
 
     let mut chart = ChartBuilder::on(&root)
-        .caption("Linear Function with Noise", ("Arial", 60))
+        .caption("Linear Function with Noise", ("sans-serif", 60))
         .margin(10)
         .set_label_area_size(LabelAreaPosition::Left, 40)
         .set_label_area_size(LabelAreaPosition::Bottom, 40)
@@ -41,7 +41,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
                 ErrorBar::new_vertical(*x, *yl, *ym, *yh, BLUE.filled(), 20)
             }),
         )?
-        .label("Downsampled")
+        .label("Down-sampled")
         .legend(|(x, y)| Path::new(vec![(x, y), (x + 20, y)], &BLUE));
 
     chart
