@@ -7,7 +7,8 @@ use crate::coord::{MeshLine, Ranged, RangedCoord};
 use crate::drawing::backend::DrawingBackend;
 use crate::drawing::DrawingAreaErrorKind;
 use crate::style::{
-    AsRelative, Color, FontDesc, IntoTextStyle, RGBColor, ShapeStyle, SizeDesc, TextStyle,
+    AsRelative, Color, FontDesc, FontFamily, FontStyle, IntoTextStyle, RGBColor, ShapeStyle,
+    SizeDesc, TextStyle,
 };
 
 /// The style used to describe the mesh for a secondary coordinate system.
@@ -159,7 +160,7 @@ where
     pub(super) format_x: &'b dyn Fn(&X::ValueType) -> String,
     pub(super) format_y: &'b dyn Fn(&Y::ValueType) -> String,
     pub(super) target: Option<&'b mut ChartContext<'a, DB, RangedCoord<X, Y>>>,
-    pub(super) _pahtom_data: PhantomData<(X, Y)>,
+    pub(super) _phantom_data: PhantomData<(X, Y)>,
     pub(super) x_tick_size: [i32; 2],
     pub(super) y_tick_size: [i32; 2],
 }
@@ -264,7 +265,7 @@ where
     }
 
     /// Set the style for the coarse grind grid
-    /// - `style`: This is the fcoarse grind grid style
+    /// - `style`: This is the coarse grind grid style
     pub fn line_style_1<T: Into<ShapeStyle>>(&mut self, style: T) -> &mut Self {
         self.line_style_1 = Some(style.into());
         self
@@ -329,8 +330,9 @@ where
         let default_mesh_color_2 = RGBColor(0, 0, 0).mix(0.1);
         let default_axis_color = RGBColor(0, 0, 0);
         let default_label_font = FontDesc::new(
-            "Arial",
+            FontFamily::SansSerif,
             f64::from((12i32).percent().max(12).in_pixels(&self.parent_size)),
+            FontStyle::Normal,
         );
 
         let mesh_style_1 = self
