@@ -42,7 +42,7 @@ impl SeriesLabelPosition {
     }
 }
 
-/// The struct to sepcify the series label of a target chart context
+/// The struct to specify the series label of a target chart context
 pub struct SeriesLabelStyle<'a, 'b, DB: DrawingBackend, CT: CoordTranslate> {
     target: &'b mut ChartContext<'a, DB, CT>,
     position: SeriesLabelPosition,
@@ -114,7 +114,10 @@ impl<'a, 'b, DB: DrawingBackend + 'a, CT: CoordTranslate> SeriesLabelStyle<'a, '
     /// Draw the series label area
     pub fn draw(&mut self) -> Result<(), DrawingAreaErrorKind<DB::ErrorType>> {
         let drawing_area = self.target.plotting_area().strip_coord_spec();
-        let default_font = ("Arial", 12).into_font();
+
+        // TODO: Issue #68 Currently generic font family doesn't load on OSX, change this after the issue
+        // resolved
+        let default_font = ("sans-serif", 12).into_font();
         let default_style: TextStyle = default_font.into();
 
         let font = {
