@@ -1,6 +1,6 @@
 /*!
-The data processing module, which implmements algorithm related to visualization of data.
-Such as, downsampling, etc.
+The data processing module, which implements algorithm related to visualization of data.
+Such as, down-sampling, etc.
 */
 /*use std::marker::PhantomData;
 use crate::drawing::backend::DrawingBackend;
