@@ -123,7 +123,7 @@ impl<'a> BitMapBackend<'a> {
 
     /// Create a new bitmap backend that generate GIF animation
     ///
-    /// When this is used, the bitmap backend acts similar to a realtime rendering backend.
+    /// When this is used, the bitmap backend acts similar to a real-time rendering backend.
     /// When the program finished drawing one frame, use `present` function to flush the frame
     /// into the GIF file.
     ///
@@ -146,6 +146,12 @@ impl<'a> BitMapBackend<'a> {
     }
 
     /// Create a new bitmap backend which only lives in-memory
+    ///
+    /// When this is used, the bitmap backend will write to a user provided [u8] array (or Vec<u8>).
+    /// Plotters uses RGB pixel format
+    ///
+    /// - `buf`: The buffer to operate
+    /// - `dimension`: The size of the image in pixels
     pub fn with_buffer(buf: &'a mut [u8], dimension: (u32, u32)) -> Self {
         Self {
             target: Target::Buffer(
@@ -166,7 +172,7 @@ impl<'a> BitMapBackend<'a> {
     }
 
     /// Split a bitmap backend vertically into several sub drawing area which allows
-    /// multithreading rendering.
+    /// multi-threading rendering.
     pub fn split(&mut self, area_size: &[u32]) -> Vec<BitMapBackend> {
         let (w, h) = self.get_size();
         let buf = self.get_raw_pixel_buffer();
@@ -636,6 +642,8 @@ fn test_draw_line_out_of_range() {
             .unwrap();
         back.draw_line((0, 1100), (999, 1100), &RED.to_rgba())
             .unwrap();
+        back.draw_rect((1100, 0), (1100, 999), &RED.to_rgba(), true)
+            .unwrap();
     }
 
     for x in 0..1000 {
