@@ -6,7 +6,7 @@ use crate::drawing::backend::{BackendCoord, BackendStyle, DrawingBackend, Drawin
 use crate::style::{Color, FontDesc, FontTransform, RGBAColor};
 
 /// The backend that is drawing on the HTML canvas
-/// TODO: Support double bufferring
+/// TODO: Support double buffering
 pub struct CanvasBackend {
     canvas: HtmlCanvasElement,
     context: CanvasRenderingContext2d,
@@ -263,8 +263,12 @@ impl DrawingBackend for CanvasBackend {
         self.context.set_text_baseline("bottom");
         self.context
             .set_fill_style(&make_canvas_color(color.clone()));
-        self.context
-            .set_font(&format!("{}px {}", font.get_size(), font.get_name()));
+        self.context.set_font(&format!(
+            "{} {}px {}",
+            font.get_style().as_str(),
+            font.get_size(),
+            font.get_name()
+        ));
         self.context
             .fill_text(text, f64::from(x), f64::from(y) + font.get_size())?;
 
