@@ -19,7 +19,7 @@ pub enum FontTransform {
 }
 
 impl FontTransform {
-    /// Compute the offset of the "top-left" cornor of the text.
+    /// Compute the offset of the "top-left" corner of the text.
     /// "Top-left" defined as the first char's top-left in reading orientation.
     pub fn offset(&self, layout: LayoutBox) -> (i32, i32) {
         match self {
@@ -30,7 +30,7 @@ impl FontTransform {
         }
     }
 
-    /// Transform the coordinate to performe the rotation
+    /// Transform the coordinate to perform the rotation
     pub fn transform(&self, x: i32, y: i32) -> (i32, i32) {
         match self {
             FontTransform::None => (x, y),
@@ -45,20 +45,108 @@ impl FontTransform {
 #[derive(Clone)]
 pub struct FontDesc<'a> {
     size: f64,
-    name: &'a str,
+    family: FontFamily<'a>,
     data: FontResult<FontDataInternal>,
     transform: FontTransform,
+    style: FontStyle,
+}
+
+/// Describes font family
+#[derive(Clone, Copy)]
+pub enum FontFamily<'a> {
+    Serif,
+    SansSerif,
+    Monospace,
+    Name(&'a str),
+}
+
+impl<'a> FontFamily<'a> {
+    pub fn as_str(&self) -> &str {
+        match self {
+            FontFamily::Serif => "serif",
+            FontFamily::SansSerif => "sans-serif",
+            FontFamily::Monospace => "monospace",
+            FontFamily::Name(face) => face,
+        }
+    }
+}
+
+impl<'a> From<&'a str> for FontFamily<'a> {
+    fn from(from: &'a str) -> FontFamily<'a> {
+        match from.to_lowercase().as_str() {
+            "serif" => FontFamily::Serif,
+            "sans-serif" => FontFamily::SansSerif,
+            "monospace" => FontFamily::Monospace,
+            _ => FontFamily::Name(from),
+        }
+    }
+}
+
+/// Describes the font style
+#[derive(Clone, Copy)]
+pub enum FontStyle {
+    Normal,
+    Oblique,
+    Italic,
+    Bold,
+}
+
+impl FontStyle {
+    pub fn as_str(&self) -> &str {
+        match self {
+            FontStyle::Normal => "normal",
+            FontStyle::Italic => "italic",
+            FontStyle::Oblique => "oblique",
+            FontStyle::Bold => "bold",
+        }
+    }
+}
+
+impl<'a> From<&'a str> for FontStyle {
+    fn from(from: &'a str) -> FontStyle {
+        match from.to_lowercase().as_str() {
+            "normal" => FontStyle::Normal,
+            "italic" => FontStyle::Italic,
+            "oblique" => FontStyle::Oblique,
+            "bold" => FontStyle::Bold,
+            _ => FontStyle::Normal,
+        }
+    }
 }
 
 impl<'a> From<&'a str> for FontDesc<'a> {
     fn from(from: &'a str) -> FontDesc<'a> {
-        FontDesc::new(from, 1.0)
+        FontDesc::new(from.into(), 1.0, FontStyle::Normal)
+    }
+}
+
+impl<'a> From<FontFamily<'a>> for FontDesc<'a> {
+    fn from(family: FontFamily<'a>) -> FontDesc<'a> {
+        FontDesc::new(family, 1.0, FontStyle::Normal)
+    }
+}
+
+impl<'a, T: Into<f64>> From<(FontFamily<'a>, T)> for FontDesc<'a> {
+    fn from((family, size): (FontFamily<'a>, T)) -> FontDesc<'a> {
+        FontDesc::new(family, size.into(), FontStyle::Normal)
     }
 }
 
 impl<'a, T: Into<f64>> From<(&'a str, T)> for FontDesc<'a> {
     fn from((typeface, size): (&'a str, T)) -> FontDesc<'a> {
-        FontDesc::new(typeface, size.into())
+        FontDesc::new(typeface.into(), size.into(), FontStyle::Normal)
+    }
+}
+
+impl<'a, T: Into<f64>, S: Into<FontStyle>> From<(FontFamily<'a>, T, S)> for FontDesc<'a> {
+    fn from((family, size, style): (FontFamily<'a>, T, S)) -> FontDesc<'a> {
+        FontDesc::new(family, size.into(), style.into())
+    }
+}
+
+impl<'a, T: Into<f64>, S: Into<FontStyle>> From<(&'a str, T, S)> for FontDesc<'a> {
+    fn from((typeface, size, style): (&'a str, T, S)) -> FontDesc<'a> {
+        FontDesc::new(typeface.into(), size.into(), style.into())
     }
 }
 
@@ -74,12 +162,13 @@ impl<'a, T: Into<FontDesc<'a>>> IntoFont<'a> for T {
 
 impl<'a> FontDesc<'a> {
     /// Create a new font
-    pub fn new(typeface: &'a str, size: f64) -> Self {
+    pub fn new(family: FontFamily<'a>, size: f64, style: FontStyle) -> Self {
         Self {
             size,
-            name: typeface,
-            data: FontDataInternal::new(typeface),
+            family,
+            data: FontDataInternal::new(family, style),
             transform: FontTransform::None,
+            style,
         }
     }
 
@@ -87,9 +176,21 @@ impl<'a> FontDesc<'a> {
     pub fn resize(&self, size: f64) -> FontDesc<'a> {
         Self {
             size,
-            name: self.name,
+            family: self.family,
             data: self.data.clone(),
             transform: self.transform.clone(),
+            style: self.style,
+        }
+    }
+
+    /// SEt the style of the font
+    pub fn style(&self, style: FontStyle) -> Self {
+        Self {
+            size: self.size,
+            family: self.family,
+            data: self.data.clone(),
+            transform: self.transform.clone(),
+            style,
         }
     }
 
@@ -97,9 +198,10 @@ impl<'a> FontDesc<'a> {
     pub fn transform(&self, trans: FontTransform) -> Self {
         Self {
             size: self.size,
-            name: self.name,
+            family: self.family,
             data: self.data.clone(),
             transform: trans,
+            style: self.style,
         }
     }
 
@@ -117,8 +219,13 @@ impl<'a> FontDesc<'a> {
     }
 
     /// Get the name of the font
-    pub fn get_name(&self) -> &'a str {
-        self.name
+    pub fn get_name(&self) -> &str {
+        self.family.as_str()
+    }
+
+    /// Get the name of the style
+    pub fn get_style(&self) -> FontStyle {
+        self.style
     }
 
     /// Get the size of font
