@@ -1,4 +1,4 @@
-/// The implementation of an actual font implmentation
+/// The implementation of an actual font implementation
 ///
 /// This exists since for the image rendering task, we want to use
 /// the system font. But in wasm application, we want the browser
@@ -25,7 +25,7 @@ pub type LayoutBox = ((i32, i32), (i32, i32));
 
 pub trait FontData: Clone {
     type ErrorType: Sized + std::error::Error + Clone;
-    fn new(face: &str) -> Result<Self, Self::ErrorType>;
+    fn new(family: FontFamily, style: FontStyle) -> Result<Self, Self::ErrorType>;
     fn estimate_layout(&self, size: f64, text: &str) -> Result<LayoutBox, Self::ErrorType>;
     fn draw<E, DrawFunc: FnMut(i32, i32, f32) -> Result<(), E>>(
         &self,
@@ -35,6 +35,6 @@ pub trait FontData: Clone {
         _trans: FontTransform,
         _draw: DrawFunc,
     ) -> Result<Result<(), E>, Self::ErrorType> {
-        panic!("The font implementation is unable to rasterize font");
+        panic!("The font implementation is unable to draw font");
     }
 }
